@@ -1,6 +1,4 @@
 /***************************************************************************
- *   ctdom.cpp                                                             *
- *   --------------------------------------------------------------------  *
  *   CT Day of Month Implementation                                        *
  *   --------------------------------------------------------------------  *
  *   Copyright (C) 1999, Gary Meyer <gary@meyer.net>                       *
@@ -44,7 +42,7 @@ string CTDayOfMonth::getName(const int ndx)
 
 void CTDayOfMonth::initializeNames()
 {
-  if (shortName[1] == "")
+  if (shortName[1].empty())
   {
     const string shortDOMName[32] =
     {
