@@ -14,7 +14,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include <unistd.h>
 
@@ -71,9 +71,9 @@ VerifyOptDlg::VerifyOptDlg( const QString & def, const QStringList& files, bool
     QListBox* fileList = new QListBox( this );
     fileList->insertStringList(files);
 
-    QPushButton* ok     = new KPushButton( KStdGuiItem::ok(), this );
+    KPushButton* ok     = new KPushButton( KStdGuiItem::ok(), this );
     ok->setFixedSize( 80, ok->sizeHint().height() );
-    QPushButton* cancel = new KPushButton( KStdGuiItem::cancel(), this );
+    KPushButton* cancel = new KPushButton( KStdGuiItem::cancel(), this );
     cancel->setFixedSize( 80, cancel->sizeHint().height() );
 
     QVBoxLayout* l1 = new QVBoxLayout( this, 8, 4 );
@@ -83,7 +83,7 @@ VerifyOptDlg::VerifyOptDlg( const QString & def, const QStringList& files, bool
     l1_1->addWidget( lbl1 );
     l1_1->addWidget( _entry, 1 );
     l1_1->addWidget( browse );
-
+    
     l1->addWidget( lbl2 );
     l1->addWidget( fileList, 1 );
 
