@@ -16,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -75,9 +75,10 @@ private:
   QString install(int installFlags, QPtrList<packageInfo> *plist, bool &test);
   QString uninstall(int uninstallFlags, QPtrList<packageInfo> *plist, bool &test);
 
-  QString doUninstall(int installFlags, QString packs, bool &test);
-  QString doInstall(int installFlags, QString packs, bool &test);
+  QString doUninstall(int installFlags, const QString &packs, bool &test);
+  QString doInstall(int installFlags, const QString &packs, bool &test);
 
+  procbuf reader;
 };
 
 #endif
