@@ -27,6 +27,8 @@
 #include "../config.h"
 #include <qpixmap.h>
 #include <qptrstack.h>
+#include <qheader.h>
+
 #include <kdebug.h>
 #include <klocale.h>
 
@@ -68,7 +70,7 @@ KListView (parent)
   
   //  setAllColumnsShowFocus(TRUE);
   setRootIsDecorated(TRUE);
-  readTreePos();
+  readTreeConfig();
   update();
   show();
 
@@ -148,10 +150,14 @@ bool KpTreeList::inMark(int x) {
   int st = 0;
   int i;
 
-  for (i = 0; i < MPOS; i++)
+    
+  QHeader* const thisHeader = header();
+  int mpos = thisHeader->mapToIndex(MPOS);
+
+  for (i = 0; i < mpos; i++)
     st += columnWidth(i);
 
-   return (x >= st && x <= st + columnWidth(MPOS));
+   return (x >= st && x <= st + columnWidth(mpos));
 }
 
 
@@ -538,35 +544,28 @@ void KpTreeList::readTreeType()
 
 //////////////////////////////////////////////////////////////////////////////
 
-void KpTreeList::writeTreePos()
+void KpTreeList::writeTreeConfig()
 {
-  int i;
-
-  KConfig *config = kapp->config();
-
-  config->setGroup("Treelist");
-
-  QString colpos;
-  for (i = 0; i < 6; i++) {
-    colpos.setNum(i);
-    config->writeEntry(colpos,columnWidth(i));
-  }
+  saveLayout( kapp->config(), "Tree");
 }
 
-void KpTreeList::readTreePos()
+void KpTreeList::readTreeConfig()
 {
-  int i, n;
-  int num[] = {185,37,180,54,95,95};
-
   KConfig *config = kapp->config();
 
-  config->setGroup("Treelist");
+  restoreLayout(config, "Tree");
 
-  QString colpos;
-  for (i = 0; i < 6; i++) {
-    colpos.setNum(i);
-    n = config->readNumEntry(colpos,num[i]);
-    setColumnWidth(i,n);
+  config->setGroup("Tree");
+  if (!config->hasKey("ColumnWidths")) {
+    int i,n;
+    int num[] = {185,37,180,54,95,95};
+
+    QString colpos;
+    for (i = 0; i < 6; i++) {
+      colpos.setNum(i);
+      n = config->readNumEntry(colpos,num[i]);
+      setColumnWidth(i,n);
+    }
   }
 }
 
