@@ -951,7 +951,7 @@ void KSVContent::multiplexEnabled (bool val)
 	   .arg (kapp->aboutData()->programName())
 	   .arg (kapp->aboutData()->programName())
 	   .arg (kapp->aboutData()->programName()),
-	   i18n("Folder Does Not Exist"));
+	   i18n("Folder Does Not Exist"),i18n("Reconfigure"),i18n("Do Not Reconfigure"));
 
 	if ( choice == KMessageBox::Yes )
 	{
