@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 /****************************************************************
@@ -51,6 +51,7 @@
 #include <qwhatsthis.h>
 #include <qsimplerichtext.h>
 
+#include <kresolver.h>
 #include <ktoolbar.h>
 #include <kkeydialog.h>
 #include <kmenubar.h>
@@ -128,8 +129,6 @@ KSVTopLevel::KSVTopLevel()
 							  this)),
     mVisible (new QCheckBox*[ksv::runlevelNumber])
 {
-  kapp->setMainWidget (this);
-
   setCaption(false);
 
   initStatusBar(); // order dependency
@@ -290,20 +289,20 @@ void KSVTopLevel::initActions ()
   createGUI(xmlFile());
 }
 
-bool KSVTopLevel::queryExit() {
-  uint res = KMessageBox::Yes;
+//
+bool KSVTopLevel::queryExit() 
+{
+  uint res = KMessageBox::Continue;
 
   if (mChanged) {
-    res = KMessageBox::warningYesNo(kapp->mainWidget(),
+    res = KMessageBox::warningContinueCancel(kapp->mainWidget(),
 				    i18n("There are unsaved changes. Are you sure you want to quit?"),
 				    i18n("Quit"),
-				    KStdGuiItem::quit(),
-				    KStdGuiItem::cancel());
+				    KStdGuiItem::quit());
 
   }
 
-  qApp->processEvents();
-  return res == KMessageBox::Yes;
+  return res == KMessageBox::Continue;
 }
 
 void KSVTopLevel::slotClearChanges()
@@ -322,15 +321,14 @@ void KSVTopLevel::slotClearChanges()
 }
 
 void KSVTopLevel::slotAcceptChanges() {
-  if (KMessageBox::Yes ==
-      KMessageBox::warningYesNo(kapp->mainWidget(),
+  if (KMessageBox::Continue ==
+      KMessageBox::warningContinueCancel(kapp->mainWidget(),
 				i18n("You're about to save the changes made to your init "
 				     "configuration. Wrong settings can "
 				     "make your system hang on startup.\n"
 				     "Do you wish to continue?"),
 				i18n("Save Configuration"),
-				KStdGuiItem::save(),
-				KStdGuiItem::cancel()))
+				KStdGuiItem::save()))
     {
       mView->slotWriteSysV();
       initView();
@@ -956,7 +954,7 @@ void KSVTopLevel::enableLogActions ()
 
 void KSVTopLevel::setCaption (bool changed)
 {
-  setPlainCaption (kapp->makeStdCaption(ksv::hostname(), true, changed));
+  setPlainCaption (kapp->makeStdCaption(KNetwork::KResolver::localHostName(), true, changed));
 }
 
 KActionCollection* KSVTopLevel::filteredActions ()
