@@ -1,3 +1,31 @@
+/* String.h
+**
+** Copyright (C) 2000,2001 by Bernhard Rosenkraenzer
+**
+** Contributions by A. Seigo and W. Bastian.
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
 /* Somewhat more sane string handling functions...                        *
  * Should be portable, therefore we aren't simply using QString.          */
 
@@ -36,7 +64,8 @@ public:
 	String mid(unsigned int start, unsigned int num=0) const;
 	String &regex(String const &expr, bool cs=true) const;
 	String &replace(String const &what, String const &with, bool all=true) const;
-	char const chr(unsigned int index) const { if(index>=size()) return 0; else return data()[index]; };
+	static String escapeForRegExp(String const &s);
+	char chr(unsigned int index) const { if(index>=size()) return 0; else return data()[index]; };
 	int length() const { return size(); }; // For compatibility with QString
 	char const *latin1() const { return cstr(); }; // For compatibility with QString
 };
