@@ -19,8 +19,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -79,7 +79,7 @@ void KControl::configChanged() // SLOT
 
 extern "C"
 {
-  KCModule *create_lilo(QWidget *parent, const char *name)
+  KDE_EXPORT KCModule *create_lilo(QWidget *parent, const char *name)
   {
     return new KControl(parent, "kcmlilo");
   }
